@@ -6,12 +6,12 @@ describe 'basic neutron' do
 
     it 'should work with no errors' do
       pp= <<-EOS
-      include ::openstack_integration
-      include ::openstack_integration::repos
-      include ::openstack_integration::rabbitmq
-      include ::openstack_integration::mysql
-      include ::openstack_integration::keystone
-      include ::openstack_integration::neutron
+      include openstack_integration
+      include openstack_integration::repos
+      include openstack_integration::rabbitmq
+      include openstack_integration::mysql
+      include openstack_integration::keystone
+      include openstack_integration::neutron
       EOS
 
 
@@ -28,8 +28,7 @@ describe 'basic neutron' do
       it 'should list OVS bridges' do
         shell("ovs-vsctl show") do |r|
           expect(r.stdout).to match(/br-int/)
-          # TODO(aschultz): renable this after timeout is sorted
-          #expect(r.stdout).to match(/br-tun/)
+          expect(r.stdout).to match(/br-tun/)
         end
       end
     end
