@@ -49,7 +49,10 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('agent/tunnel_csum').with_value(['<SERVICE DEFAULT>'])
       should contain_neutron_agent_ovs('ovs/datapath_type').with_value(['<SERVICE DEFAULT>'])
       should contain_neutron_agent_ovs('ovs/vhostuser_socket_dir').with_value(['<SERVICE DEFAULT>'])
-      should contain_neutron_agent_ovs('ovs/ovsdb_interface').with_value(['<SERVICE DEFAULT>'])
+      should contain_neutron_agent_ovs('ovs/ovsdb_timeout').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/of_connect_timeout').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/of_request_timeout').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovs('ovs/of_inactivity_probe').with_value('<SERVICE DEFAULT>')
       should contain_neutron_agent_ovs('ovs/integration_bridge').with_value(p[:integration_bridge])
       should contain_neutron_agent_ovs('securitygroup/firewall_driver').\
         with_value(p[:firewall_driver])
@@ -61,6 +64,8 @@ describe 'neutron::agents::ml2::ovs' do
       should contain_neutron_agent_ovs('ovs/int_peer_patch_port').with_ensure('absent')
       should contain_neutron_agent_ovs('ovs/tun_peer_patch_port').with_ensure('absent')
       should contain_neutron_agent_ovs('agent/tunnel_types').with_ensure('absent')
+      should contain_neutron_agent_ovs('ovs/igmp_snooping_enable').with_value('<SERVICE DEFAULT>')
+      should_not contain_neutron_agent_ovs('ovs/resource_provider_bandwidths')
     end
 
     it 'installs neutron ovs agent package' do
@@ -193,6 +198,41 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
+    context 'when setting ovsdb_timeout' do
+      before :each do
+        params.merge!( :ovsdb_timeout => 30 )
+      end
+
+      it 'configures ovsdb_timeout' do
+        should contain_neutron_agent_ovs('ovs/ovsdb_timeout').with_value(params[:ovsdb_timeout])
+      end
+    end
+
+    context 'when setting of_connect_timeout and of_request_timeout' do
+      before :each do
+        params.merge!( :of_connect_timeout => 30,
+                       :of_request_timeout => 20 )
+      end
+
+      it 'configures of_connect_timeout' do
+        should contain_neutron_agent_ovs('ovs/of_connect_timeout').with_value(params[:of_connect_timeout])
+      end
+
+      it 'configures of_request_timeout' do
+        should contain_neutron_agent_ovs('ovs/of_request_timeout').with_value(params[:of_request_timeout])
+      end
+    end
+
+    context 'when setting of_inactivity_probe' do
+      before :each do
+        params.merge!( :of_inactivity_probe => 20 )
+      end
+
+      it 'configures of_inactivity_probe' do
+        should contain_neutron_agent_ovs('ovs/of_inactivity_probe').with_value(params[:of_inactivity_probe])
+      end
+    end
+
     context 'when supplying extensions for ML2 plugin' do
       before :each do
         params.merge!(:extensions => ['qos'])
@@ -272,25 +312,6 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
-    context 'when supplying ovsdb_interface' do
-      context 'with incorrect value' do
-        before :each do
-          params.merge!(:ovsdb_interface => 'random')
-        end
-
-        it { should raise_error(Puppet::Error, /A value of \$ovsdb_interface is incorrect. The allowed values are vsctl and native/) }
-      end
-
-      context 'with supported value' do
-        before :each do
-          params.merge!(:ovsdb_interface => 'native')
-        end
-        it 'should configure ovsdb_interface for ovs' do
-          should contain_neutron_agent_ovs('ovs/ovsdb_interface').with_value('native')
-        end
-      end
-    end
-
     context 'when enabling dpdk with manage vswitch disabled' do
       before :each do
         params.merge!(:enable_dpdk => true, :manage_vswitch => false)
@@ -298,6 +319,16 @@ describe 'neutron::agents::ml2::ovs' do
 
       it { should raise_error(Puppet::Error, /Enabling DPDK without manage vswitch does not have any effect/) }
     end
+
+    context 'when resource_provider_bandwidths is set' do
+      before :each do
+        params.merge!(:resource_provider_bandwidths => ['provider-a', 'provider-b'])
+      end
+
+      it { should contain_neutron_agent_ovs('ovs/resource_provider_bandwidths').\
+        with_value('provider-a,provider-b') }
+    end
+
   end
 
   shared_examples 'neutron::agents::ml2::ovs on Debian' do
@@ -338,6 +369,16 @@ describe 'neutron::agents::ml2::ovs' do
       end
     end
 
+    context 'with IGMP snooping enabled' do
+      before :each do
+        params.merge!(:igmp_snooping_enable => true)
+      end
+
+      it 'configure neutron/plugins/ml2/ml2_conf.ini' do
+        should contain_neutron_agent_ovs('ovs/igmp_snooping_enable').with_value(true)
+      end
+    end
+
   end
 
   on_supported_os({
