@@ -2,13 +2,13 @@ require 'spec_helper'
 
 describe 'neutron::plugins::ml2::nuage' do
   let :pre_condition do
-    "class { '::neutron':
+    "class { 'neutron':
        core_plugin     => 'ml2' }
-     class { '::neutron::keystone::authtoken':
+     class { 'neutron::keystone::authtoken':
        password => 'passw0rd',
      }
      class { 'neutron::server': }
-     class { '::neutron::plugins::ml2':
+     class { 'neutron::plugins::ml2':
        mechanism_drivers => ['nuage'] }"
   end
 
@@ -83,7 +83,7 @@ describe 'neutron::plugins::ml2::nuage' do
 
     context 'configure ml2 nuage with wrong mechanism_driver configuration' do
       let :pre_condition do
-        "class { '::neutron::plugins::ml2':
+        "class { 'neutron::plugins::ml2':
           mechanism_drivers => ['bar'] }"
       end
 
