@@ -3,7 +3,7 @@ require 'spec_helper'
 describe 'neutron::server' do
   let :pre_condition do
     "class { 'neutron': }
-     class { '::neutron::keystone::authtoken':
+     class { 'neutron::keystone::authtoken':
        password => 'passw0rd',
      }"
   end
@@ -17,13 +17,6 @@ describe 'neutron::server' do
       :package_ensure           => 'present',
       :enabled                  => true,
       :auth_strategy            => 'keystone',
-      :database_connection      => 'sqlite:////var/lib/neutron/ovs.sqlite',
-      :database_max_retries     => 10,
-      :database_idle_timeout    => 3600,
-      :database_retry_interval  => 10,
-      :database_min_pool_size   => 1,
-      :database_max_pool_size   => 10,
-      :database_max_overflow    => 20,
       :sync_db                  => false,
       :router_scheduler_driver  => 'neutron.scheduler.l3_agent_scheduler.ChanceScheduler',
       :l3_ha                    => false,
@@ -77,6 +70,7 @@ describe 'neutron::server' do
         :max_request_body_size        => '<SERVICE DEFAULT>',
       )
       should contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_config('ovs/igmp_snooping_enable').with_value('<SERVICE DEFAULT>')
     end
 
     context 'with manage_service as false' do
@@ -229,8 +223,8 @@ describe 'neutron::server' do
 
       let :pre_condition do
         "class { 'neutron': }
-         include ::apache
-         class { '::neutron::keystone::authtoken':
+         include apache
+         class { 'neutron::keystone::authtoken':
            password => 'passw0rd',
          }"
       end
@@ -268,6 +262,16 @@ describe 'neutron::server' do
       it { should contain_neutron_config('DEFAULT/ovs_integration_bridge').with_value('br-int') }
     end
 
+    context 'with IGMP snooping enabled' do
+      before :each do
+        params.merge!(:igmp_snooping_enable => true)
+      end
+
+      it 'configure neutron.conf' do
+        should contain_neutron_config('ovs/igmp_snooping_enable').with_value(true)
+      end
+    end
+
   end
 
   shared_examples 'VPNaaS and FWaaS package installation' do
